@@ -33,9 +33,10 @@
 #  define KALARMCAL_DEPRECATED_NO_EXPORT KALARMCAL_NO_EXPORT KALARMCAL_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KALARMCAL_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KALARMCAL_NO_DEPRECATED
+#    define KALARMCAL_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
